netapp_ontap.models.aggregate_block_storage_hybrid_cache_simulated_raid_groups API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_block_storage_hybrid_cache_simulated_raid_groups`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateBlockStorageHybridCacheSimulatedRaidGroupsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateBlockStorageHybridCacheSimulatedRaidGroups object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `added_data_disk_count: Size GET POST PATCH`

    Number of added data disks in RAID group.

  `added_parity_disk_count: Size GET POST PATCH`

    Number of added parity disks in RAID group.

  `existing_data_disk_count: Size GET POST PATCH`

    Number of existing data disks in the RAID group.

  `existing_parity_disk_count: Size GET POST PATCH`

    Number of existing parity disks in the RAID group.

  `is_partition: bool GET POST PATCH`

    Indicates whether the disk is partitioned (true) or whole (false).

  `name: str GET POST PATCH`

    Name of the raid group.

  `usable_size: Size GET POST PATCH`

    Usable size of each disk, in bytes.